import axios from 'axios'
import { INIT_SALE_URL, CREATE_PRODUCT_URL, CREATE_CUSTOMER_URL, PROCESS_SALE_URL } from '@/constants/resourcePaths'
import { INIT_SALE, NOTIFY, EXPLODE_DATA, CREATE_PRODUCT, CREATE_CUSTOMER, RECEIVE_PRODUCT, RECEIVE_CUSTOMER, CREATE_SALE } from '@/constants/actionTypes'

const actions = {
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    [NOTIFY] ({ commit }, payload) {
        openerp.web.notification.do_warn('Atención', payload)
        return false
    },
    /**
     * 
     * @param {*} param0 
     */
    [INIT_SALE] ({ dispatch }) {
        return axios.get(INIT_SALE_URL).then(response => {
            dispatch('explodeData', response.data)
        }).catch(error => {
            console.log(error)
        })
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    [EXPLODE_DATA] ({ dispatch }, payload) {
        for (let value in payload) {
            dispatch(`init${value[0].toUpperCase()}${value.slice(1)}`, payload[value])
        }
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    [CREATE_PRODUCT] ({ dispatch }, payload) {
        const data = {
            jsonrpc: '2.0',
            method: 'call',
            params: {
                ...payload
            }
        }

        return axios.post(CREATE_PRODUCT_URL, data).then(response => {
            dispatch(RECEIVE_PRODUCT, response.data.result)
        }).catch(error => {
            console.log(error)
        })
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    [CREATE_CUSTOMER] ({ dispatch }, payload) {
        const data = {
            jsonrpc: '2.0',
            method: 'call',
            params: {
                ...payload
            }
        }

        return axios.post(CREATE_CUSTOMER_URL, data).then(response => {
            dispatch(RECEIVE_CUSTOMER, response.data.result)
        }).catch(error => {
            console.log(error)
        })
    },
    /**
     * 
     * @param {*} param0 
     */
    [CREATE_SALE] ({ getters , dispatch }, payload) {
        const data = {
            jsonrpc: '2.0',
            method: 'call',
            params: {
                items: getters.cartItems.map(item => {
                    return {
                        id: item.id,
                        quantity: item.quantity,
                        price: item.price
                    }
                }),
                total: getters.cartTotal,
                customerId: getters.selectedCustomer.id,
                paymentTermId: getters.selectedPaymentTerm.id,
                journalId: getters.selectedJournal.id,
                payment: getters.cartTotal
            }
        }

        return axios.post(PROCESS_SALE_URL, data).then(response => {
            console.log(response)
        }).catch(error => {
            console.log(error)
        })
    }
}

export default actions